@@ -1,5 +1,4 @@
-
-context("ISO 8601 moment.js")
+# ISO 8601 moment.js ----
 
 ## http://momentjs.com/docs/#/parsing/string/
 ## Slightly modified, because it is _not_ allowed to
@@ -51,7 +50,7 @@ test_that("Examples from moment.js", {
 
 })
 
-context("ISO 8601 Pelago")
+# ISO 8601 Pelago ----
 
 ## http://www.pelagodesign.com/blog/2009/05/20/
 ## iso-8601-date-validation-that-doesnt-suck/
@@ -107,7 +106,7 @@ test_that("Pelago examples", {
 
 })
 
-context("ISO 8601 Pelago non-matching")
+# ISO 8601 Pelago non-matching ----
 
 test_that("Pelago non-matching", {
 
@@ -146,7 +145,7 @@ test_that("Pelago non-matching", {
 
 })
 
-context("ISO week dates")
+# ISO week dates ----
 
 test_that("Exotic ISO week dates are OK", {
 
